@@ -73,7 +73,7 @@ fn main() -> Result<(), io::Error> {
     loop {
         let mut line = selected;
         if let Ok(size) = terminal.size() {
-            if size.height <= 10 {
+            if size.height < 10 || size.width < 10 {
                 continue;
             }
 
